@@ -188,9 +188,19 @@ class FlowsSplit(Enum):
     Grades = "grades"  #:
     Products = "products"  #:
     OriginCountries = "origin countries"  #:
+    OriginSubcontinents = "origin subcontinents"  #:
+    OriginContinents = "origin continents"  #:
+    OriginTradingRegions = "origin trading regions"  #:
+    OriginPorts = "origin ports"
+    DestinationTradingRegions = "destination trading regions"  #:
     DestinationCountries = "destination countries"  #:
+    DestinationSubcontinents = "destination subcontinents"  #:
+    DestinationContinents = "destination continents"  #:
     OriginInstallations = "origin installations"  #:
     DestinationInstallations = "destination installations"  #:
+    DestinationPorts = "destination ports"
+    OriginPadds = "origin padds"  #:
+    DestinationPadds = "destination padds"  #:
     VesselType = "vessel type"  #:
     TradeStatus = "trade status"  #:
     Sources = "sources "  #:
@@ -198,6 +208,8 @@ class FlowsSplit(Enum):
     Routes = "routes"  #:
     Buyers = "buyer"  #:
     Sellers = "seller"  #:
+    VesselTypeOil = "vessel type oil"
+    VesselTypeCpp = "vessel type cpp"
 
 
 class FlowsPeriod(Enum):
@@ -374,10 +386,20 @@ class FleetMetricsSplit(Enum):
     Grades = "grades"  #:
     Products = "products"  #:
     OriginCountries = "origin countries"  #:
+    OriginTradingRegions = "origin trading regions"
+    DestinationTradingRegions = "destination trading regions"
+    OriginContinents = "origin continents"
+    OriginSubcontinents = "origin subcontinents"
+    DestinationSubcontinents = "destination subcontinents"
+    OriginPorts = "origin ports"
+    DestinationPorts = "destination ports"
+    DestinationContinents = "destination continents"
     DestinationCountries = "destination countries"  #:
     OriginInstallations = "origin installations"  #:
     DestinationInstallations = "destination installations"  #:
     VesselType = "vessel type"  #:
+    VesselTypeOil = "vessel type oil"
+    VesselTypeCpp = "vessel type cpp"
     TradeStatus = "trade status"  #:
     Charterers = "charterers"  #:
     Buyer = "buyer"  #:
@@ -515,3 +537,9 @@ class InventoriesSplit(Enum):
     ByPlayer = "byPlayer"  #:
     ByTankType = "byTankType"  #:
     ByOnshoreOffshoreStatus = "byOnshoreOffshoreStatus"  #:
+
+
+class InventoriesDronePeriod(Enum):
+    MidWeeks = "midweeks"  #:
+    EiaWeeks = "eia"  #:
+    Days = "days"  #:
